<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="UTF-8" />
    <title>Flask Demo</title>
    <link
      rel="stylesheet"
      href="{{ url_for('static', filename='styles.css') }}"
    />
  </head>
  <body>
    <h1>Hello from Flask 👋</h1>
    <p>This page is styled with CSS and powered by JS.</p>
    <button onclick="showMessage()">Click me</button>

    <script src="{{ url_for('static', filename='script.js') }}"></script>
  </body>
</html>
